@@ -8,10 +8,10 @@ urlpatterns = patterns(
         name='lava.scheduler'),
     url(r'^active_jobs_json$', 
         'index_active_jobs_json',
-        name='lava.scheduler'),
+        name='lava.scheduler.active_jobs_json'),
     url(r'^devices_json$', 
         'index_devices_json',
-        name='lava.scheduler'),
+        name='lava.scheduler.index_devices_json'),
     url(r'^alljobs$', 
         'job_list', 
         name='lava.scheduler.job.list'),
